import React, { useEffect, useState } from "react";
import { Container, Col, Row, Button } from "react-bootstrap";
import { Link } from "react-router-dom";
import SpecialOffers from "components/ourOffers/specialOffers";
import ProductList from "components/ourproducts/productList";
import { connect, useDispatch } from "react-redux";
import { actions as productActions } from "@redux/productRedux";
import { actions as categoryActions } from "@redux/categoryRedux";
import CategoryFilter from "components/form/categoryFilter";
import { faArrowCircleRight } from "@fortawesome/free-solid-svg-icons";
import ShortByFilter from "components/form/shortByFilter";
import NestleFilter from "components/form/nestleFilter";
import PriceRangeFilter from "components/form/priceRangeFilter";
import OfferDataAccess from "dataAccess/offerDataAccess";
import SuperSaleProducts from "components/ourOffers/superSale";
import { Helmet } from "react-helmet";

const AllProducts = (props: any) => {
  const dispatch = useDispatch();

  const [selectedCategories, setSelectedCategories] = useState(["4", "7"]);
  const [selectedShortByItem, setSelectedShortByItem] = useState([]);
  const [selectedNestle, setSelectedNestle] = useState(["2"]);
  const [specialOffer, setSpecialOffer] = useState([]);

  useEffect(() => {
    dispatch(productActions.clearProductList());
    dispatch(productActions.getAllProducts());
  }, [dispatch]);

  useEffect(() => {
    OfferDataAccess.getSpecialOfferProducts()
      .then((data) => {
        setSpecialOffer(data);
      })
      .catch((error) => {});
  }, []);

  let categoryValues = [
    { id: "1", name: "Category1" },
    { id: "2", name: "Category2" },
    { id: "3", name: "Category3" },
    { id: "4", name: "Category4" },
    { id: "5", name: "Category5" },
    { id: "6", name: "Category6" },
    { id: "7", name: "Category7" },
  ];

  let shortByItemValues = [
    { id: "1", name: "Price(Low to High)" },
    { id: "2", name: "Price(High to Low)" },
    { id: "3", name: "Top reviews" },
    { id: "4", name: "Ascending" },
    { id: "5", name: "Descending" },
    { id: "6", name: "Others" },
  ];

  let nestleValues = [
    { id: "1", name: "Modhumoti" },
    { id: "2", name: "Nestle" },
    { id: "3", name: "Basundhora" },
  ];

  return (
    <div className="our-products-all mt-6">
      <Helmet>
        <title> Genx | Products All </title>
        <meta name="description" content="Our All Products" />
      </Helmet>
      <div className="products-section">
        <Row>
          <Col xl={4} lg={4} md={12} sm={12} xs={12}>
            <p className="header"> Our Products (All) </p>
            <p className="our-products-des">
              {/* ShopStick provides you more than 1000+ products from each category.
                     <br /> You can choose products from here as well as filter also. */}
            </p>
          </Col>
          {/*
               <Col xl={8} lg={8} md={12} sm={12} xs={12} className="product-filter-section">
                  <div className="filter-content">
                     
                     <span className="filter-btn-main">
                        <span>Date 0f arrival</span>
                     </span>
                     <span className="filter-btn-main">
                        <span>Search products &nbsp; </span>
                     </span>

                     <ShortByFilter
                        label="Short by"
                        values={shortByItemValues}
                        selectedValues={selectedShortByItem}
                        setSelectedValues={(values) => {
                           setSelectedShortByItem(values);
                        }}
                     />

                     <PriceRangeFilter
                        label="Price" 
                        onClear={() => {}}
                        onApply={() => {}} 
                     />

                     <NestleFilter
                        label="Nestle"
                        values={nestleValues}
                        selectedValues={selectedNestle}
                        setSelectedValues={(values) => {
                           setSelectedNestle(values);
                        }}
                        onClear={() => {}}
                        onApply={() => {}}
                     />
                     <CategoryFilter
                        label="Category"
                        values={categoryValues}
                        selectedValues={selectedCategories}
                        setSelectedValues={(values) => {
                           setSelectedCategories(values);
                        }}
                        onClear={() => {}}
                        onApply={() => {}}
                     />
                  </div>
               </Col> */}
        </Row>

        <ProductList />
        {!props.product.productsLoading &&
          props.product.productsInfo.current_page &&
          props.product.productsInfo.current_page !==
            props.product.productsInfo.last_page && (
            <Row style={{ textAlign: "center", marginTop: "20px" }}>
              <Col>
                <Button
                  className="load-more"
                  variant="primary"
                  onClick={() => {
                    dispatch(
                      productActions.getAllProducts(
                        props.product.productsInfo.current_page + 1
                      )
                    );
                  }}
                >
                  <span className="btn-text">Load More</span>
                </Button>
              </Col>
            </Row>
          )}
      </div>{" "}
      {/* all products show end.... */}
      <SpecialOffers />
    </div>
  );
};

const mapStateToProps = ({ product, category }) => ({
  product,
  category,
});

export default connect(mapStateToProps)(AllProducts);
